@@ -27,6 +27,7 @@ const GstPbutils = imports.gi.GstPbutils;
 
 const Mainloop = imports.mainloop;
 
+const Application = imports.application;
 const MainWindow = imports.mainWindow;
 const Waveform = imports.waveform;
 
@@ -77,11 +78,13 @@ const _TENTH_SEC = 100000000;
         this.playState = PipelineStates.PLAYING;
                 
         if (this.ret == Gst.StateChangeReturn.FAILURE) {
-            this._showErrorDialog(_('Unable to set the playbin to the playing state.')); 
+            this._showErrorDialog(_('Unable to play recording')); 
             this.onEndOfStream();
         } else if (this.ret == Gst.StateChangeReturn.SUCCESS) {        
             MainWindow.view.setVolume(); 
-        }  
+        }
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy, this.play);
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy, this.play); 
     },
     
     pausePlaying: function() {
@@ -128,8 +131,8 @@ const _TENTH_SEC = 100000000;
             break;
                 
         case Gst.MessageType.ERROR:
-            let errMsg = "Error:" + message.parse_error();
-            this._showErrorDialog(_(errMsg));
+            let errorMessage = message.parse_error();
+            this._showErrorDialog(errorMessage);              
             this.play.set_state(Gst.State.NULL);
             this.playState = PipelineStates.STOPPED;
             this.playBus.remove_signal_watch();
@@ -218,13 +221,19 @@ const _TENTH_SEC = 100000000;
         this._fileToPlay = MainWindow.view.loadPlay(this._selected);
     },
     
-    _showErrorDialog: function(errorStr) {
-        let errorDialog = new Gtk.MessageDialog ({ modal: true,
-                                                   destroy_with_parent: true,
+    _showErrorDialog: function(errorStrOne, errorStrTwo) {
+        let errorDialog = new Gtk.MessageDialog ({ destroy_with_parent: true,
                                                    buttons: Gtk.ButtonsType.OK,
-                                                   message_type: Gtk.MessageType.WARNING,
-                                                   text: errorStr });
+                                                   message_type: Gtk.MessageType.WARNING });
 
+        if (errorStrOne != null) {
+            errorDialog.set_property('text', errorStrOne);
+        }
+         
+        if (errorStrTwo != null)
+            errorDialog.set_property('secondary-text', errorStrTwo);
+
+        errorDialog.set_transient_for(Gio.Application.get_default().get_active_window());
         errorDialog.connect ('response', Lang.bind(this,
             function() {
                 errorDialog.destroy();
